@@ -1,9 +1,9 @@
 import numpy 
 
 def fat_perc_male_cm_exp(abdomen, neck, height):
-    abdomen_inc = abdomen / 2.54
+    abdomen_inc = abdomen / (2.54)
     neck_inc = neck / (2.54)
-    height_inc = height/(2.54)
+    height_inc = height/ (2.54)
     perc = (86.010 *numpy.log10(abdomen_inc - neck_inc)) - (70.041 *numpy.log10(height_inc)) + 36.76
     a= round(perc,2)
     if a>2 and a<5:
